package com.caimei365.tools.mapper;

import com.caimei365.tools.model.po.*;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;

/**
 * Description
 *
 * @author : Charles
 * @date : 2022/11/2
 */
@Mapper
public interface CmBehaviorRecordMapper {
    /**
     * 获取供应商名称
     * @param shopId
     * @return
     */
    String getShopName(@Param("shopId") Integer shopId);

    /**
     * 获取页面默认标签
     * @param type
     * @return
     */
    String getPageLabel(@Param("type") Integer type);

    /**
     * 获取商品详情标签
     * @param productId
     * @return
     */
    String getProductPageLabel(@Param("productId") Integer productId);

    /**
     * 获取文章详情标签
     * @param infoId
     * @return
     */
    String getInfoPageLabel(@Param("Id") Integer infoId);

    /**
     * 采美百科标签
     * @param id
     * @return
     */
    String getBaiKePageLabel(@Param("Id") Integer id);

    /**
     * 用户行为记录
     * @param cmBehaviorRecordPo
     * @return
     */
    void insertRecord(CmBehaviorRecordPo cmBehaviorRecordPo);

    /**
     * 当天访问网站IP、userId
     * @param cmBehaviorRecordPo
     */
    List<CmBehaviorRecordPo> toDateRecode(CmBehaviorRecordPo cmBehaviorRecordPo);

    /**
     * 当天访问网站IP、userId的详细数据
     * @param cmBehaviorRecordPo
     */
    List<CmBehaviorRecordPo> toDateIPTimeRecode(CmBehaviorRecordPo cmBehaviorRecordPo);

    /**
     * 计算真是访问时长
     * @param cmBehaviorRecordPo
     */
    void updateDuration(CmBehaviorRecordPo cmBehaviorRecordPo);

    /**
     * 查询所有老数据
     * @return
     */
    List<CmUserPo> findList(@Param("startId") Integer startId, @Param("endId") Integer endId);

    /**
     * sku信息
     * @return
     */
    List<CmSkuPo> skuList();

    /**
     * 修改sku信息
     * @param skuPo
     */
    void updateSku(CmSkuPo skuPo);
    /**
     * 修改老数据ip所在地
     * @param userPo
     */
    void updateOldData(CmUserPo userPo);

    CmVipCouponPo selSvipCoupon(@Param("startTime") String startTime, @Param("endTime") String endTime);

    /**
     * 将本季度优惠券开放
     * @param cmVipCouponPo
     */
    void updateSvipCoupon(CmVipCouponPo cmVipCouponPo);

    /**
     * 生成下一季度优惠券
     * @param cmVipCouponPo
     */
    void insertVipCouponMonth(CmVipCouponPo cmVipCouponPo);

    List<CmCouponPo> selCoupon();

    void updateCoupon(CmCouponPo cmCouponPo);

    void insertCoupon(CmCouponPo cmCouponPo);

    List<CmCouponAssociatePo> selCouponPro(@Param("couponId") Integer couponId);

    /**
     * 插入新优惠券商品
     * @param associate
     */
    void insertCouponAssociate(CmCouponAssociatePo associate);

    Integer selSvipCouponById();

    /**
     * vip优惠券月份关系
     * @param cmVipCouponRelation
     */
    void insertRelation(CmVipCouponRelation cmVipCouponRelation);

    /**
     * 小程序 openId
     * @param accessDate
     * @return
     */
    List<String> getRecodeOpenId(@Param("accessDate") String accessDate);

    /**
     * 小程序中每个openid有多个用户
     * @param accessDate
     * @return
     */
    List<CmBehaviorRecordPo> getCuxOpen(@Param("accessDate") String accessDate);

    /**
     * 查询openId 对应的用户
     * @param accessDate
     * @param openIdList
     * @return
     */
    List<CmBehaviorRecordPo> getRecordOpenIdInfo(@Param("accessDate") String accessDate, @Param("openIdList") List<String> openIdList);

    /**
     * 游客id
     * @param accessDate
     * @return
     */
    List<String> getRecodeTouristId(@Param("accessDate") String accessDate);

    /**
     * 网站中每个touristId有多个用户
     * @param accessDate
     * @return
     */
    List<CmBehaviorRecordPo> getCuxTourist(@Param("accessDate") String accessDate);

    /**
     * 游客对应用户信息
     * @param accessDate
     * @param touristIds
     * @return
     */
    List<CmBehaviorTouristInfoPo> getTouristInfo(@Param("accessDate") String accessDate, @Param("touristIds") List<String> touristIds);

    /**
     * 获取游客id对应的ip
     * @param accessDate
     * @param touristId
     * @return
     */
    String getTouristIdByIp(@Param("accessDate") String accessDate, @Param("touristId") String touristId);

    /**
     * 获取userId 访问属性
     * @param accessDate
     * @param openId
     * @param touristId
     * @return
     */
    List<Integer> getUserIdAttribute(@Param("accessDate") String accessDate, @Param("openId") String openId, @Param("touristId") String touristId);
    /**
     * 修改数据
     * @param cmBehaviorRecordPo
     */
    void updateBehavior(CmBehaviorRecordPo cmBehaviorRecordPo);

    /**
     * 根据游客Id修改用户浏览信息
     * @param cmBehaviorRecordPo
     */
    void updateBehaviorByTouristId(CmBehaviorRecordPo cmBehaviorRecordPo);

    /**
     * 获取游客ip 与注册用户相同的访问
     * @param accessDate
     * @return
     */
    List<CmBehaviorRecordPo> getUserAndBehavior(@Param("accessDate") String accessDate);

    /**
     * 合并游客与用户相同ip的访问数据
     * @param userId
     * @param recordId
     */
    void updateBehaviorTourist(@Param("userId") Integer userId, @Param("recordId") Integer recordId);
    /**
     * 用户昨日数据
     * @param accessDate
     * @return
     */
    List<CmBehaviorRecordPo> selYesterdayList(@Param("accessDate") String accessDate);

    /**
     * 插入昨日数据
     * @param cmBehaviorRecordPo
     */
    void insertYesterdayList(CmBehaviorRecordPo cmBehaviorRecordPo);

    /**
     * 查询今日所有用户行为数据
     * @param accessDate
     * @return
     */
    List<CmBehaviorRecordPo> selTodayData(@Param("accessDate") String accessDate);

    /**
     * 关联供应商数据
     * @param accessDate
     * @return
     */
    List<CmBehaviorRecordPo> selDataList(@Param("accessDate") String accessDate);

    /**
     * 获取该用户该天的标签
     * @param ip
     * @param accessDate
     * @param userId
     * @return
     */
    List<String> getBehaviorPageLabel(@Param("ip") String ip, @Param("accessDate") String accessDate, @Param("userId") String userId);

    /**
     * 获取该用户该天的浏览页面 - 页面
     * @param ip
     * @param accessDate
     * @param userId
     * @return
     */
    List<Integer> getBehaviorPageType(@Param("ip") String ip, @Param("accessDate") String accessDate, @Param("userId") String userId);

    /**
     * 将今日数据存储到今日数据表
     * @param cmBehaviorRecordPo 参数
     */
    void inBehaviorToday(CmBehaviorRecordPo cmBehaviorRecordPo);

    /**
     * 清除今日用户数据数据
     */
    void delTodayData();

    /**
     * 所有供应商关联标签
     * @return
     */
    List<String> shopKeyword();

    /**
     * 查询供应商id
     * @param strList 页面标签
     * @return 返回
     */
    List<Integer> shopIds(@Param("strList") List<String> strList);

    /**
     * 获取是否关联供应商
     * @param ShopId
     * @return
     */
    Integer selShopId(@Param("shopId") Integer ShopId);
    /**
     * 添加关联供应商
     * @param recordId 用户行为记录id
     * @param shopId 供应商id
     */
    void insertShopId(@Param("recordId") Integer recordId, @Param("shopId") Integer shopId);

    /**
     * 个人机构注册ip
     * @return
     */
    List<CmBehaviorRecordPo> selRegisterIP(Integer startId, Integer endId);

    /**
     * 省份
     * @return
     */
    Integer selProvince(@Param("regionPro") String regionPro);

    /**
     * 市
     * @return
     */
    AddressPo selCity(@Param("regionCity") String regionCity);

    /**
     * 更新机构地址数据
     */
    void upClubAddress(@Param("clubId") String clubId, @Param("provinceId") Integer provinceId, @Param("cityId") Integer cityId);

    /**
     * 需要统计的供应商Id
     * @return
     */
    List<Integer> getShopId();

    /**
     * 需要统计的供应商商品Id
     * @return
     */
    List<Integer> getProductId(@Param("shopId") Integer shopId);

    /**
     * 需要统计的供应商文章Id
     * @param shopId
     * @return
     */
    List<Integer> getShopInfoId(@Param("shopId") Integer shopId);

    /**
     * 需要统计的供应商搜索词Id
     * @param shopId
     * @return
     */
    List<SearchFrequencyVo> getShopKeywordId(@Param("shopId") Integer shopId);

    /**
     * 检索统计信息
     * @param accessDate
     * @param pageType
     * @param pagePath
     * @return
     */
    CmBehaviorRecordPo getBehaviorList(@Param("accessDate") String accessDate , @Param("pageType") Integer pageType, @Param("pagePath") String pagePath);

    /**
     * 添加供应商主页统计数据
     * @param cmPageShopPo
     */
    void insertPageShop(CmPageShopPo cmPageShopPo);

    /**
     * 添加供应商商品统计数据
     * @param cmPageShopProductPo
     */
    void insertPageProduct(CmPageShopProductPo cmPageShopProductPo);

    /**
     * 添加供应商文章统计数据
     * @param cmPageShopInfoPo
     */
    void insertPageInfo(CmPageShopInfoPo cmPageShopInfoPo);

    /**
     * 添加供应商搜索词统计数据
     * @param cmPageShopKeywordPo
     */
    void insertPageKeyword(CmPageShopKeywordPo cmPageShopKeywordPo);

    /**
     * 机构Id
     * @return
     */
    List<Integer> getClubId();

    /**
     * 机构咨询记录静态、动态标签
     * @param clubId
     * @param startTime
     * @param endTime
     * @return
     */
    List<CmClubLabelPo> getClubLabel(@Param("clubId") Integer clubId,@Param("startTime") String startTime,@Param("endTime") String endTime);

    /**
     * 用户访问记录数据
     * @param clubId
     * @param startTime
     * @param endTime
     * @return
     */
    List<CmBehaviorRecordPo> getClubBehavior(@Param("clubId") Integer clubId,@Param("startTime") String startTime,@Param("endTime") String endTime);

    /**
     * 动态标签
     * @return
     */
    List<String> getTrendsKeyword();

    /**
     * 静态标签
     * @return
     */
    List<String> getStateKeyword();

    /**
     * 机构动态标签
     * @return
     */
    List<CmClubLabelPo> getClubTrendsKeyword();

    /**
     * 机构静态标签
     * @return
     */
    List<CmClubLabelPo> getClubStateKeyword();

    /**
     * 保存机构标签
     */
    void insertClubLabel(CmClubLabelPo cmClubLabelPo);

    /**
     * 修改机构标签
     * @param cmClubLabelPo
     */
    void updateClubLabel(CmClubLabelPo cmClubLabelPo);
}

