package com.caimei365.tools.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.caimei365.tools.mapper.MessageMapper;
import com.caimei365.tools.model.po.ClubPo;
import com.caimei365.tools.model.po.ServiceproviderPo;
import com.caimei365.tools.service.MessageService;
import com.caimei365.tools.utils.RequestUtil;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

/**
 * Description
 *
 * @author : Charles
 * @date : 2023/11/2
 */
@Slf4j
@Service
public class MessageServiceImpl implements MessageService {

    @Value("${wx.mini-app-id}")
    private String miniAppId;
    @Value("${wx.mini-app-secret}")
    private String miniAppSecret;
    @Value("${wx.crm-app-id}")
    private String crmAppId;
    @Value("${wx.crm-app-secret}")
    private String crmAppSecret;

    @Resource private MessageMapper messageMapper;

    @Override
    public void UnActiveMessage() {
        SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        Date date = new Date();
        // 协销信息
        List<ServiceproviderPo> serviceInfo = messageMapper.getServiceInfo();
        for (ServiceproviderPo serviceprovider: serviceInfo) {
            List<ClubPo> unActiveClub = messageMapper.getUnActiveClub(serviceprovider.getServiceProviderId());
            String clubName = "";
            if (null != unActiveClub && unActiveClub.size() > 0) {
                for (ClubPo club : unActiveClub) {
                    if (StringUtils.isNotBlank(club.getName())) {
                        clubName += club.getName()+"  ";
                    } else if (StringUtils.isNotBlank(club.getLinkMan())) {
                        clubName += club.getLinkMan()+"  ";
                    }
                }
                if (clubName.length() > 10) {
                    String substring = clubName.substring(0, 9);
                    clubName = substring + "等" + unActiveClub.size() + "家机构";
                }
                JSONObject first = new JSONObject();
                first.put("value", "请及时跟进您名下的不活跃客户");
                JSONObject keyword1 = new JSONObject();
                keyword1.put("value", "不活跃客户跟进提醒");
                JSONObject keyword2 = new JSONObject();
                keyword2.put("value", clubName);
                JSONObject keyword3 = new JSONObject();
                keyword3.put("value", dateFormat.format(date));
                JSONObject remark = new JSONObject();
                remark.put("value", "点击查看详情，查看咨询记录详情。");

                JSONObject data = new JSONObject();
                data.put("first", first);
                data.put("keyword1", keyword1);
                data.put("keyword2", keyword2);
                data.put("keyword3", keyword3);
                data.put("remark", remark);

                JSONObject miniProgram = new JSONObject();
                miniProgram.put("appid", miniAppId);
                // 跳转链接
                 miniProgram.put("pagepath", "/pages/seller/club/club-inactive-list?serviceProviderId="+serviceprovider.getServiceProviderId());
                // 获取openId
                String openid = messageMapper.getOpenidListByPermission(serviceprovider.getUnionId());

                JSONObject json = new JSONObject(new LinkedHashMap());
                json.put("touser", openid);
                json.put("template_id", "xvOy9dwbCK-GeCUBnNV6XLzw_afavHBtT5wKgH_ZIpU");
                json.put("url", "https://www.caimei365.com/");
                json.put("miniprogram", miniProgram);
                json.put("data", data);
                // json 字符串
                String jsonString = json.toJSONString();
                log.info(">>>>>>>>推送微信模板消息：" + jsonString);
                try {
                    String requestUrl = "https://api.weixin.qq.com/cgi-bin/message/template/send?access_token=" + getAccessToken();
                    // 发送请求
                    String result = RequestUtil.httpRequest(requestUrl, "POST", jsonString);
                    log.info(">>>>>>>>推送结果：" + result);
                } catch (Exception e) {
                    log.info("推送微信模板消息失败：" + e);
                }
            }
        }
    }


    /**
     * 微信公众号获取access_token
     *
     * @return access_token
     */
    public String getAccessToken() throws Exception {
        String link = "https://api.weixin.qq.com/cgi-bin/token?grant_type=client_credential&appid=APPID&secret=APPSECRET";
        link = link.replace("APPID", crmAppId);
        link = link.replace("APPSECRET", crmAppSecret);
        String result = RequestUtil.sendGet(link);
        log.info("微信公众号获取access_token>>>" + link);
        log.info("微信公众号获取access_token>>>" + result);
        Map<String, Object> map = JSONObject.parseObject(result, Map.class);
        return (String) map.get("access_token");
    }
}
