package com.caimei365.tools.service.impl;

import com.caimei365.tools.mapper.BaseMapper;
import com.caimei365.tools.model.po.SearchFrequencyVo;
import com.caimei365.tools.service.ProductService;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.List;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/10/26
 */
@Service
@Slf4j
public class ProductServiceImpl implements ProductService {
    @Resource
    private BaseMapper baseMapper;

    /**
     * 统计关键词及次数
     *
     * @param fromType
     * @param path
     * @param keyword
     * @return
     */
    @Override
    public void conKeyword(Integer fromType, String path, String keyword, String linkageFlag) {
        /**
         * 关键词库v1.1
         * 任意符合条件的记录直接插入cm_label_source，保留元数据一年
         * cm_user_search_frequency中keyword为唯一，表中已有添加一次frequency，表中没有则新增，修改时刷新searchTime 最近一次搜索时间
         */
        SearchFrequencyVo sea = new SearchFrequencyVo();
        SearchFrequencyVo id = baseMapper.findKeywordId(keyword);
        if (id != null) {
            //已存在改次数，不存在插入 如果加上本次查询，有三次，则立即修改推荐标记，置入推荐列表
            if (id.getFrequency() >= 2 && id.getRecommendStatus() != 1) {
                baseMapper.updateKeywordRecommend(id.getId());
            } else {
                baseMapper.updateKeywordTimes(id.getId());
            }
            sea.setId(id.getId());
        } else {
            sea.setFrequency(1);
            sea.setKeyword(keyword);
            baseMapper.saveInfo(sea);
        }
        //统计次数
        baseMapper.addCmPraiseStatistics("6",sea.getId());
        sea.setPath(path);
        baseMapper.insertLabelSource(sea);
    }

    @Override
    public void updateAllKeyword() {
        baseMapper.updateAllKeyword();
    }

    @Override
    public void updateKeywordRecommend() {
        //查询本周时间内搜索大于等于三次的
        Calendar instance = Calendar.getInstance();
        instance.setTime(new Date());
        instance.add(Calendar.WEEK_OF_MONTH, -1);
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        List<Integer> ids = baseMapper.getRecommendKeyword(format.format(instance.getTime()));
        baseMapper.updateRecommend(ids);
    }
}
