package com.caimei365.tools.service.impl;

import com.caimei365.tools.mapper.BaseMapper;
import com.caimei365.tools.model.po.SysUser;
import com.caimei365.tools.service.SysUserService;
import com.caimei365.tools.utils.RedisService;
import com.caimei365.tools.utils.constant.ConstantKey;
import io.jsonwebtoken.Jwts;
import io.jsonwebtoken.SignatureAlgorithm;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Calendar;
import java.util.Date;
import java.util.List;

/**
 * @author zzj
 */
@Service
@Slf4j
public class SysUserServiceImpl implements SysUserService {

    @Resource
    private BaseMapper baseMapper;

    @Resource
    private RedisService redisService;

    @Override
    public String getNewToken(String id) {
        SysUser user = baseMapper.findUserNameById(id);
        List<String> roleListByUserId = baseMapper.getRoleNamesByUserId(user.getId());
        String token = createToken(user.getUserName(), roleListByUserId);
        log.info("token-----------------------" + token);
        return token;
    }

    public String createToken(String username, List<String> roleList) {
        Calendar calendar = Calendar.getInstance();
        // 设置签发时间
        calendar.setTime(new Date());
        Date now = calendar.getTime();
        // 设置过期时间
        calendar.add(Calendar.MINUTE, ConstantKey.TOKEN_EXPIRE);
        Date time = calendar.getTime();
        String token = Jwts.builder()
                .setSubject(username + "-" + roleList)
                // 签发时间
                .setIssuedAt(now)
                // 过期时间
                .setExpiration(time)
                // 自定义算法与签名：这里算法采用HS512，常量中定义签名key
                .signWith(SignatureAlgorithm.HS512, ConstantKey.SIGNING_KEY)
                .compact();
        // 将token存入redis,并设置超时时间为token过期时间
        long expire = time.getTime() - now.getTime();
        redisService.set(token, token, expire);
        return token;
    }
}
