package com.caimei365.tools.task;

import com.caimei365.tools.service.CmBehaviorRecordService;
import com.caimei365.tools.service.CmOrganValueSystemService;
import com.caimei365.tools.service.CmVipCouponService;
import com.caimei365.tools.service.MessageService;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;

import javax.annotation.Resource;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;

/**
 * Description
 *
 * @author : Charles
 * @date : 2022/10/24
 */
@Slf4j
@Configuration
@EnableScheduling
@RequiredArgsConstructor
public class CmOrganValueSystemTask {

    @Resource
    private CmOrganValueSystemService cmOrganValueSystemService;

    @Resource
    private CmBehaviorRecordService cmBehaviorRecordService;

    @Resource
    private CmVipCouponService cmVipCouponService;

    @Resource
    private MessageService messageService;

    /**
     * 每天生成用户活跃状态
     */
    @Scheduled(cron = "0 13 0 * * ?")
    public void organData() {
        cmOrganValueSystemService.insertOrgan();
    }

    /**
     * 每月一号更新用户价值
     */
    @Scheduled(cron = "0 15 0 1 * ?")
    public void organCustomer() {
        cmOrganValueSystemService.insertcustomer();
    }

    /**
     * 每小时统计计算真实访问时长
     */
    @Scheduled(cron = "0 0 * * * ?")
    public void behaviorAccessDuration() {
        cmBehaviorRecordService.updateBehaviorTime();
    }

    /**
     * 每天修改前一天的符合条件的数据 合并ip
     */
    @Scheduled(cron = "0 5 0 * * ?")
    public void updateBehavior() {
        cmBehaviorRecordService.updateBehaviorUser();
    }

    /**
     * 每天生成前一天的符用户行为列表数据
     */
    @Scheduled(cron = "0 15 0 * * ?")
    public void insertBehaviorUser() {
        cmBehaviorRecordService.insertBehaviorUser();
    }

    /**
     * 每个季度创建专属优惠券
     */
    @Scheduled(cron = "0 00 00 1 5,8,11,2 ?")
    public void svipCoupon() {
        cmVipCouponService.openCoupon();
    }

    /**
     * 生成今日用户行为数据
     */
    @Scheduled(cron = "0 0/10 * * * ?")
    public void insertBehaviorToday() {
        cmBehaviorRecordService.insertTodayData();
    }

    /**
     * 生成页面统计数据
     */
    @Scheduled(cron = "0 0 8 * * ?")
    public void pageStatistics() {
        cmBehaviorRecordService.pageStatistics();
    }

    /**
     * 每天10点 给协销微信模板提醒 -- 不活跃机构
     */
    @Scheduled(cron = "0 0 10 * * ?")
    public void getMessageSer() {
        messageService.UnActiveMessage();
    }

    /**
     * 每天获取前一天机构需求标签
     */
    @Scheduled(cron = "0 20 0 * * ?")
    public void getClubDemand() {
        SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd");
        Date date = new Date();
        String endTime = dateFormat.format(date);
        Calendar instance = Calendar.getInstance();
        instance.setTime(date);
        instance.add(Calendar.DAY_OF_MONTH, -1);
        Date time = instance.getTime();
        String startTime = dateFormat.format(time);
        cmBehaviorRecordService.clubDemand(startTime, endTime);
    }
}
