package com.caimei365.tools.task;

import com.caimei365.tools.service.ProductService;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;

import javax.annotation.Resource;

/**
 * @author zzj
 */
@Slf4j
@Configuration
@EnableScheduling
@RequiredArgsConstructor
public class KeywordLabelTask {

    @Resource
    private ProductService productService;
    /**
     * 1.关键词每周仅推荐一次；
     *
     * 2.当前本周内，用户搜索次数≥3次时，则立刻进行推荐，当推荐一次后，且本周内无需再推荐；
     *
     * 3.当上一周的关键词搜索次数未满足推荐条件时，则无需累计到下周计算搜索次数，且下一周需重新计算；
     *
     * 4.如关键词已被推荐过，且没有加入到标签库的，则在下一周满搜索条件时即重新推荐一次，依此类推；
     *
     * 5.已推荐过的关键词在未处理的情况下，又再次进行推荐时，则进行清除，保留最新的一次推荐记录；
     *
     * 6.当关键词已加入到标签库的，则无需再进行推荐；
     *
     * 7.当前关键词在关键搜索推荐被加入标签库后，这里的加入标签库按钮也许同步隐藏,标签库状态变为已添加；
     *
     * 8.被推荐的关键词如半年内未处理的，则进行清除；
     *
     *
     *
     *
     * 每周星期天晚11点实行一次
     * 把cm_user_search_frequency未加入标签库的全表置为未推荐,忽略置为未忽略
     * 查询cm_label_source是否存在本周内已查询三次置为推荐
     *
     */
    @Scheduled(cron = "* * 23 * * 1")
    public void checkKeyword() {
        //把cm_user_search_frequency未加入标签库的全表置为未推荐,忽略置为未忽略
        productService.updateAllKeyword();
        //查询满足搜索条件的，修改推荐标记
        productService.updateKeywordRecommend();
    }

}
