package com.caimei365.tools.task;

import com.alibaba.fastjson.JSONObject;
import com.caimei365.tools.mapper.MessageCenterMapper;
import com.caimei365.tools.mapper.OrderClubMapper;
import com.caimei365.tools.model.dto.message.InsideMessage;
import com.caimei365.tools.model.dto.message.MessageModel;
import com.caimei365.tools.model.dto.message.MqInfo;
import com.caimei365.tools.model.dto.message.WechatTemplateMessage;
import com.caimei365.tools.model.dto.message.enums.MessageType;
import com.caimei365.tools.model.po.*;
import com.caimei365.tools.service.MessageSender;
import com.caimei365.tools.service.WeChatService;
import com.caimei365.tools.utils.SmsUtil;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;

import javax.annotation.Resource;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.List;
import java.util.concurrent.atomic.AtomicReference;

/**
 * Description
 *
 * @author : Charles
 * @date : 2022/7/29
 */
@Slf4j
@Configuration
@EnableScheduling
@RequiredArgsConstructor
public class ShopMessTask {

    @Resource
    private MessageCenterMapper messageCenterMapper;

    @Resource
    private OrderClubMapper orderClubMapper;

    @Resource
    private MessageSender messageSender;

    @Scheduled(cron = "0 0 15 * * ?")
//    @Scheduled(cron = "1/180 * * * * ?")
    public void outTimePutAwayFee() {
        log.info("-------------------------------上架费过期推送开始-------------------------------");
        putAwayFee(0);
        putAwayFee(7);
        putAwayFee(30);
        log.info("-------------------------------上架费过期推送结束-------------------------------");
    }

    //        @Scheduled(cron = "0 0/2 * * * ?")
    @Scheduled(cron = "0 0 11 * * ?")
    public void outTimeQualification() {
        log.info("---------------------------开始检测商品资质证书是否过期-------------------------------");
        //1,7,30,90
        qualification(0);
        qualification(7);
        qualification(30);
        qualification(91);
        log.info("---------------------------检测商品资质证书是否过期结束-------------------------------");
    }

    public void qualification(Integer day) {
        StringBuilder productNames = new StringBuilder();
        StringBuilder productIds = new StringBuilder();
        List<QualificationPo> pro = messageCenterMapper.findOutTimeQualification(day);
        log.info(day+"天证书过期的有-------------------》"+pro.toString());
        String contentDay = 0 == day ? "今天" : 7 == day ? "7天" : 30 == day ? "一个月" : "三个月";
        String content = "该商品的资质证书将于" + contentDay + "后失效，请及时登录采美网站上传新证书。";
        String theme = "以下械字号商品的资质证书将于" + contentDay + "后失效，请及时提醒供应商更换证书。";
        MessageCenterPo messageCenter = new MessageCenterPo();
        messageCenter.userType(2).messageType(2).shopMessType(5).content(content);
        WechatTemplateMessage wechat = new WechatTemplateMessage();
        wechat.templateId("gpD9TqBpkgaw3YSM_JPk4WSTwKZY0hxrBCH0SjzNKY4").url("https://www.caimei365.com/").appid("wxf3cd4ae0cdd11c36")
                .first("您好，您有商品资质证书即将到期。").pagePath("");
        pro.forEach(p -> {
            productNames.append("(").append(p.productId()).append(")").append(p.productName());
            productIds.append(p.productId()).append(",");
            messageCenter.productId(p.productId());
            messageCenterMapper.addMessageCenter(messageCenter);
            ArrayList<String> strings = new ArrayList<>();
            strings.add(p.shopName());
            strings.add("医疗器械注册证");
            strings.add(p.qualificationNo());
            strings.add(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()));
            //todo 傻逼写法，拿不到值，有空再改
            String openid = messageCenterMapper.getOpenidListByPermission(p.shopId());
            wechat.remark(p.productName()).openId(openid).keyWords(strings);
            MessageModel<WechatTemplateMessage> we = new MessageModel<>();
            messageSender.messageSend(we.code(MessageType.WECHAT_TEMPLATE_MESSAGE).info(wechat));
            log.info("资质证书" + day + "天-----productNames------------>" + productNames + "productIds----------->" + productIds);
        });
        if (null != pro && pro.size() > 0) {
            String names = productNames.toString();
            String ids = productIds.toString();
            names = names.endsWith(",") ? names.substring(0, names.lastIndexOf(",")) : names;
            ids = ids.endsWith(",") ? ids.substring(0, ids.lastIndexOf(",")) : ids;
            if (names.length() > 10) {
                names = StringUtils.strip(names.substring(0, 11));
                names += "...";
            }
            Notification notification = new Notification();
            notification.theme(theme).shopContent(names).productId(ids);
            messageCenterMapper.addNotification(notification);
        }
    }

    public void putAwayFee(Integer day) {
        List<ShopReceiptVo> shopIds = messageCenterMapper.findExpireShopId(day);
        String contentDay = day > 7 ? "30" : 7 == day ? "7" : "今";
        StringBuilder shopNames = new StringBuilder();
        StringBuilder shopsId = new StringBuilder();
        String firsts = "尊敬的采美供应商用户，您的账号维护费用" + contentDay + "天后即将到期！";
        String content = "您的供应商账号上架费将于" + contentDay + "日后到期，到期后将无法发布和编辑商品，同时也会影响到其他采美提供的支持服务。请联系采美工作人员进行续费，联系电话0755-22907771 或15338851365。退订回T";
        shopIds.forEach(s -> {
            //站内信
            MessageModel<InsideMessage> insideMessageMessageModel = new MessageModel<>();
            insideMessageMessageModel.code(MessageType.WEB_INSIDE_MESSAGE)
                    .mqInfo(new MqInfo().topic("MessageLine").delay(3).async(0))
                    .info(new InsideMessage().shopId(s.getShopId()).userType(2)
                            .messageType(3).shopTieredType(1).content(contentDay + "日后到期"));
            messageSender.messageSend(insideMessageMessageModel);
            //短信
            String mobile = messageCenterMapper.contractMobiles(s.getShopId());
            String result = SmsUtil.sendSms(3, mobile, content);
            log.info("发送结果：" + result + "，短信内容：" + content);
            //微信模板消息
            MessageModel<WechatTemplateMessage> wechatTemplateMessageMessageModel = new MessageModel<>();
            String pagePath = "https://www.caimei365.com/";
            //todo 傻逼写法，拿不到值，有空再改
            String openid = messageCenterMapper.getOpenidListByPermission(s.getShopId());
            ArrayList<String> strings = new ArrayList<>();
            strings.add("维护费");
            strings.add("年付");
            strings.add(s.getValidityDate());
            strings.add(s.getDateStrings());
            strings.add(s.getReceiptAmount().toString());
            WechatTemplateMessage weChat = new WechatTemplateMessage().first(firsts).openId(openid).pagePath(pagePath).keyWords(strings)
                    .templateId("jYUIq63wP6mGFvkgNHgTOXAgF7j6h_VZKgST_-2fqCo").remark("为了更好给您服务，请及时联系采美客服缴费!").appid("wx91c4152b60ca91a3").url(pagePath);
            MessageModel<WechatTemplateMessage> weChatMessage = wechatTemplateMessageMessageModel.code(MessageType.WECHAT_TEMPLATE_MESSAGE).info(weChat);
            messageSender.messageSend(weChatMessage);
            shopNames.append(s.getShopName()).append(",");
            shopsId.append(s.getShopId()).append(",");
            log.info("上架费" + day + "天--shopName---------------->" + shopNames + "shopIds---------------->" + shopIds);
        });
        if (null != shopIds && shopIds.size() > 0) {
            String s = shopNames.toString();
            String sn = shopsId.toString();
            String shopDay = 0 == day ? "今天" : 7 == day ? "7天" : "一个月";
            String theme = "以下供应商的上架费将于" + shopDay + "后到期，请及时提醒供应商续费。";
            s = s.endsWith(",") ? s.substring(0, s.lastIndexOf(",")) : s;
            sn = sn.endsWith(",") ? sn.substring(0, sn.lastIndexOf(",")) : sn;
            Notification notification = new Notification();
            notification.theme(theme).shopContent(s).shopId(sn);
            messageCenterMapper.addNotification(notification);
        }
    }

    @Scheduled(cron = "0 0 15 * * ?")
    public void putAwayFeeForManager() {
        log.info("---------------------------上架费三个月过期推送开始-------------------------------");
        //后台上架费三个月过期推送
        List<ShopReceiptVo> shopIds = messageCenterMapper.findExpireShopId(90);
        log.info("上架费三个月过期的有----------------》" + shopIds.toString());
        StringBuilder shopNames = new StringBuilder();
        StringBuilder shopsId = new StringBuilder();
        shopIds.forEach(s -> {
            shopNames.append(s.getShopName()).append(",");
            shopsId.append(s.getShopId()).append(",");
            log.info("上架费三个月----------------->shopName---------------->" + shopNames + "shopIds---------------->" + shopIds);
        });
        if (null != shopIds && shopIds.size() > 0) {
            String s = shopNames.toString();
            String sn = shopsId.toString();
            s = s.endsWith(",") ? s.substring(0, s.lastIndexOf(",")) : s;
            sn = sn.endsWith(",") ? sn.substring(0, sn.lastIndexOf(",")) : sn;
            Notification notification = new Notification();
            notification.theme("以下供应商的上架费将于3个月后到期，请及时提醒供应商续费。").shopContent(s).shopId(sn);
            messageCenterMapper.addNotification(notification);
        }
        log.info("---------------------------上架费三个月过期推送结束-------------------------------");
    }

    @Scheduled(cron = "0 0 10 15 * ?")
    public void gwc() {
        log.info("------------开始推送购物车相关短信------------------------>");
        List<Integer> userId = orderClubMapper.userIds();
        userId.forEach(userIds -> {
            OrderVo orderVo = orderClubMapper.getcartNess(userIds);
            if (orderVo.getProName() != null) {
                String name = orderVo.getProName();
                if (name.length() > 10) {
                    name = StringUtils.strip(name.substring(0, 11));
                    name += "...";
                }
                if (orderVo.getMobile() != null) {
                    String content;
                    String mobile;
                    if (6 == orderVo.getUserIdentity()) {
                        mobile= orderVo.getMobile().substring(1);
                        content = "【颜选美学】有件商品" + name + "在您购物车内已经待了很久啦，快去微信搜索“颜选美学”小程序登录查看吧。关注公众号“颜选美学”获取更多优惠和精彩资讯。退订回T";
                    } else {
                        mobile= orderVo.getMobile();
                        content = "有件商品" + name + "在您购物车内已经待了很久啦，快戳采美网站链接www.caimei365.com或微信搜索“采美采购商城”小程序登录采美平台去购物车看看吧。关注公众号“采美网”获取更多优惠和精彩资讯。退订回T";
                    }
                    //发送短信 【购物车】
                    String result = SmsUtil.sendSms(3, mobile, content);
                    JSONObject json = (JSONObject) JSONObject.parse(result);
                    log.info("发送结果：" + result + "，短信内容：" + content);
                    if (null != json && json.getInteger("code") == 0) {
                        log.info(orderVo.getMobile() + "发送成功");
                    } else {
                        log.error(orderVo.getMobile() + "发送失败");
                    }
                } else {
                    log.error("号码为空" + "发送失败");
                }
            }
        });
        log.info("------------推送购物车相关短信-结束----------------------->");
    }

    /**
     * 每天12点推送
     * 优惠券领取后离失效日只剩7天还没使用，在当天中午12点推送给领取了该优惠券的用户（谁领的给谁发短信）
     * <p>
     * 若优惠券有限期小于15天，则上述情况不推送
     * <p>
     * 短信模板：【采美365】您有100元优惠券将于7日后过期，快戳采美网站链接www.caimei365.com
     * 或微信搜索“采美采购商城”小程序登录采美平台查看使用吧。关注公众号“采美网”获取更多优惠和精彩资讯。
     */
    @Scheduled(cron = "0 0 12 * * ?")
    private void Timerw() {
        log.info("----------------------------优惠券七天后过期---------------------------------");
        List<CmCouponPo> coupons = messageCenterMapper.findOutTimeCoupons(7);
        log.info("优惠券七天过期的有----------------》" + coupons.toString());
        MessageCenterPo messageCenter = new MessageCenterPo();
        messageCenter.userType(1).messageType(4).couponMessageType(2).content("7天");
        coupons.forEach(c -> {
            messageCenter.clubId(c.getClubId()).couponFee(c.getCouponAmount().doubleValue()).couponType(c.getCouponType());
            messageCenterMapper.addMessageCenter(messageCenter);
            String content = "您有" + c.getCouponAmount() + "元优惠券将于7日后过期，" +
                    "快戳采美网站链接www.caimei365.com/M2Tr98CG 或微信搜索“采美采购商城”小程序登录采美平台查看使用吧。关注公众号“采美网”获取更多优惠和精彩资讯。退订回T";
            SmsUtil.sendSms(3, content, c.getBindMobile());
        });
    }


    /**
     * 优惠券领取后没有使用，在失效日当天，上午10推送给领取了该优惠券的用户（谁领的给谁发短信）
     * <p>
     * 短信模板：【采美365】您有100元优惠券今日过期，快戳采美网站链接www.caimei365.com/M2Tr98CG
     * 或微信搜索“采美采购商城”小程序登录采美平台查看使用吧。关注公众号“采美网”获取更多优惠和精彩资讯。
     */
    @Scheduled(cron = "0 0 10 * * ?")
    private void Timeto() {
        log.info("----------------------------优惠券一天后过期---------------------------------");
        List<CmCouponPo> coupons = messageCenterMapper.findOutTimeCoupons(1);
        log.info("优惠券一天过期的有-----------------》" + coupons.toString());
        MessageCenterPo messageCenter = new MessageCenterPo();
        messageCenter.userType(1).messageType(4).couponMessageType(2).content("1天");
        coupons.forEach(c -> {
            messageCenter.clubId(c.getClubId()).couponFee(c.getCouponAmount().doubleValue()).couponType(c.getCouponType());
            messageCenterMapper.addMessageCenter(messageCenter);
            String content = "您有" + c.getCouponAmount() + "元优惠券将于7日后过期，" +
                    "快戳采美网站链接www.caimei365.com/M2Tr98CG 或微信搜索“采美采购商城”小程序登录采美平台查看使用吧。关注公众号“采美网”获取更多优惠和精彩资讯。退订回T";
            SmsUtil.sendSms(3, content, c.getBindMobile());
        });
    }


//    @Scheduled(cron = "0 0 15 * * ?")
    private void Timeth() {
        /**
         * 优惠券离失效日只剩3天还没领取，在当天，下午3点推送
         *
         * 【采美365】您有100元优惠券尚未领取，优惠券将于3日后失效，快戳采美网站链接www.caimei365.com/M2Tr98CG
         * 或微信搜索“采美采购商城”小程序登录采美平台领取使用吧。关注公众号“采美网”获取更多优惠和精彩资讯。
         */
        log.info("----------------------------优惠券三天后过期---------------------------------");
        List<CmCouponPo> coupons = messageCenterMapper.findOutTimeCoupons(3);
        log.info("优惠券三天过期的有-------------------》" + coupons.toString());
        MessageCenterPo messageCenter = new MessageCenterPo();
        messageCenter.userType(1).messageType(4).couponMessageType(3).content("3天");
        coupons.forEach(c -> {
            messageCenter.clubId(c.getClubId()).couponFee(c.getCouponAmount().doubleValue()).couponType(c.getCouponType());
            messageCenterMapper.addMessageCenter(messageCenter);
            String content = "您有" + c.getCouponAmount() + "元优惠券将于3日后过期，" +
                    "快戳采美网站链接www.caimei365.com/M2Tr98CG 或微信搜索“采美采购商城”小程序登录采美平台查看使用吧。关注公众号“采美网”获取更多优惠和精彩资讯。退订回T";
            SmsUtil.sendSms(3, content, c.getBindMobile());
        });
    }

    @Scheduled(cron = "0 0/60 * * * ?")
    private void config() throws ParseException {
        SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        SimpleDateFormat dateF = new SimpleDateFormat("yyyy-MM-dd HH");
        SimpleDateFormat dateR = new SimpleDateFormat("yyyy-MM-dd");
        String current = dateFormat.format(new Date());
        //订单超时未确认的时间
        Integer hour = orderClubMapper.cmorderconfig("confirmOverTime");
        //待收款 待发货超时
        Integer hours = orderClubMapper.cmorderconfig("receivableOverTime");
        //待收款 待发货超时
        Integer hourmex = orderClubMapper.cmorderconfig("autoReceiptGoodsTime");
        //前日期
        Calendar calendar = Calendar.getInstance();
        String day = dateF.format(new Date());
        Date receipttime = dateF.parse(day);
        calendar.setTime(receipttime);
        calendar.add(Calendar.HOUR, -hour);
        String hTime = dateF.format(calendar.getTime());
        List<OrderVo> orderStatuslist = orderClubMapper.oredrStatus();
        log.info(">>>>订单因超时未付款站内推送");
        orderStatuslist.forEach(order -> {
            Date i = new Date();
            try {
                i = dateF.parse(order.getOrderTime());
            } catch (ParseException e) {
                e.printStackTrace();
            }
            Integer num = hTime.compareTo(dateF.format(i));
            if (num == 0) {
                MessageCenterPo messageCenter = new MessageCenterPo();
                //推送信息中心-交易物流-待确认超时
                if (6 == order.getUserIdentity()) {
                    messageCenter.thisId(order.getUserId()).userType(4);
                }else {
                    messageCenter.clubId(order.getClubId()).userType(1);
                }
                messageCenter.messageType(1).orderId(order.getOrderId()).orderMessageType(4)
                        .content("您的订单因超时未付款，系统已自动取消订单！").time(current);
                messageCenterMapper.addMessageCenter(messageCenter);
            }
        });

        //待收款 待发货超时
        Calendar calendars = Calendar.getInstance();
        String days = dateF.format(new Date());
        Date receiptime = dateF.parse(days);
        calendars.setTime(receiptime);
        calendars.add(Calendar.HOUR, -hours);
        String hTimes = dateF.format(calendars.getTime());
        List<OrderVo> cmorderConfigStatus = orderClubMapper.cmorderConfigStatus();
        log.info(">>>>待收款 待发货超时站内推送!");
        cmorderConfigStatus.forEach(order -> {
            Date i = new Date();
            try {
                i = dateF.parse(order.getOrderTime());
            } catch (ParseException e) {
                e.printStackTrace();
            }
            Integer num = hTimes.compareTo(dateF.format(i));
            if (num == 0) {
                MessageCenterPo messageCenter = new MessageCenterPo();
                //推送信息中心-账户通知
                messageCenter.clubId(order.getClubId()).userType(1).messageType(1).orderId(order.getOrderId()).
                        orderMessageType(6).time(current);
                messageCenterMapper.addMessageCenter(messageCenter);
            }
        });

        Calendar calendarmax = Calendar.getInstance();
        String daymax = dateR.format(new Date());
        Date receiptimemax = dateR.parse(daymax);
        calendarmax.setTime(receiptimemax);
        calendarmax.add(Calendar.DATE, -hourmex);
        String hTimemax = dateR.format(calendarmax.getTime());
        List<OrderVo> cmorderStatus = orderClubMapper.cmorderConfigStatus();
        log.info(">>>>订单因超时已被系统自动确认收货站内推送!");
        cmorderStatus.forEach(order -> {
            Date i = new Date();
            try {
                i = dateR.parse(order.getOrderTime());
            } catch (ParseException e) {
                e.printStackTrace();
            }
            Integer num = hTimemax.compareTo(dateR.format(i));
            if (num == 0) {
                MessageCenterPo messageCenter = new MessageCenterPo();
                //推送信息中心-账户通知
                if (6 == order.getUserIdentity()) {
                    messageCenter.thisId(order.getUserId()).userType(4);
                }else {
                    messageCenter.clubId(order.getClubId()).userType(1);
                }
                messageCenter.messageType(1).orderId(order.getOrderId())
                        .orderMessageType(6).content("您的订单因超时已被系统自动确认收货!").time(current);
                messageCenterMapper.addMessageCenter(messageCenter);
            }
        });
    }
}
